function setup = TEST_SETUP(setup)

is_ml = is_matlab();

if(nargin==0)
   xT = 10+rand*50
   yT = randn*10
   T = 3+rand*10
   w = randn(2,1)
   g = 2+rand(1)*20
   rho = 10^(-rand(1)*3)/10

   setup.xT = xT;
   setup.yT = yT;
   setup.T = T;
   setup.w = w;
   setup.g = g;
   setup.rho = rho;
else
   xT = setup.xT;
   yT = setup.yT;
   T = setup.T;
   w = setup.w;
   g = setup.g;
   rho = setup.rho;
end

do_movie = is_matlab();

%
%  do core computation
%
vk = berechne_projektil([xT; yT], T, g, w, rho);


int_func = @(t,y) func_f(y, g, rho, w);

% compute the trajectory of the bullet
if( is_ml )
   h=0.1;
   show_times = [(h:h:(T-h)), T];
   [TOUT, YOUT] = ode45(int_func, [0, show_times], [0; 0; vk]);
else
   [TOUT, YOUT] = ode45_octave(int_func, [0, T], [0; 0; vk]);
end
TOUT = TOUT'; YOUT = YOUT';

qs = YOUT(1:2, :);

YMAX = max([max(qs(2, :)), yT+10,  10]);
YMIN = min([min(qs(2, :)), yT-10, -10]);

XMAX = max([max(qs(1, :)), xT+10,  10]);
XMIN = min([min(qs(1, :)), xT-10, -10]);

x_tank = [ 0, 1, 2,-1, 0, 1,-2,-1, 0, ];
y_tank = [ 0, 0, 1, 1, 2, 1, 1, 0, 0, ] - 1;

ms = 20;
barrel = 2;

% plot wind
wind_xs = linspace(XMIN, XMAX, 4);
wind_ys = linspace(YMIN, YMAX, 4);
[WX, WY] = meshgrid(wind_xs, wind_ys);
if( is_ml )
   quiver(WX, WY, w(1)*ones(size(WX)), w(2)*ones(size(WY)), 0.4, 'b');
else
   quiver(WX, WY, w(1)*ones(size(WX)), w(2)*ones(size(WY)));
end
hold on;

% plot terrain
SP = 4;
surf_x = [ -SP,  SP, xT-SP, xT+SP ];
surf_y = [-1, -1, yT-1, yT-1 ];
plot(surf_x, surf_y, 'g-' );

% plot enemy tank
plot(x_tank+xT, y_tank+yT, 'b-');
plot(xT, yT, 'b.', 'MarkerSize', ms);
enemy_phi = 4/5*pi;
plot( [xT, barrel*cos(enemy_phi)+xT], ...
      [yT, barrel*sin(enemy_phi)+yT], 'b-', 'LineWidth', 3 );

% plot firing tank
plot(x_tank, y_tank, 'k-');
%plot(0, YMAX, 'k+');
plot(0,0, 'k.', 'MarkerSize', ms);

phi = angle(vk(1)+1i*vk(2));
plot( [0, barrel*cos(phi)], [0, barrel*sin(phi)], 'k-', 'LineWidth', 3 );

%
% plot the flight path of the bullet
%
if( is_ml )
   last = YOUT(1:2, 1);

   for ind=2:length(TOUT)
      t = TOUT(ind);
      next = YOUT(1:2, ind);

      plot([last(1), next(1)], [last(2), next(2)], 'm-');
      if( do_movie )
         title(['Zeitpunkt = ',num2str(t), '; Zielzeitpunkt = ', num2str(T)]);
         drawnow;
      end
      last=next;
   end
else
   plot( YOUT(1, :), YOUT(2, :), 'm-');
   last = YOUT(1:2, end);
end

err = norm( last-[xT;yT] );

title(['Zielzeitpunkt = ', num2str(T), '; Fehler = ', num2str(err) ]);

maxerr = 1e-9;
if( ~is_ml )
   maxerr = 1e-2;
end

if( err > maxerr )
   text(xT/2, yT/2, 'fail', 'FontSize', 30, 'Color', [1 0 0]);
else
   plot( last(1), last(2), 'r*', 'MarkerSize', 20, 'LineWidth', 3 )
end

hold off;
